package com.supervision.manage.service.impl;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.supervision.manage.service.DiseasePhysicalManageService;
import com.supervision.model.DiseaseAncillary;
import com.supervision.model.DiseasePhysical;
import com.supervision.service.DiseasePhysicalService;
import com.supervision.vo.manage.DiseasePhysicalResVo;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;
@Service
@RequiredArgsConstructor
public class DiseasePhysicalManageServiceImpl implements DiseasePhysicalManageService {

    private final DiseasePhysicalService diseasePhysicalService;


    @Override
    public List<DiseasePhysicalResVo> queryListByDiseaseId(String diseaseId) {

        Assert.isTrue(StrUtil.isNotEmpty(diseaseId),"id不能为空");

        return diseasePhysicalService.queryListByDiseaseId(diseaseId);
    }

    @Override
    public DiseasePhysical savePhysical(DiseasePhysical diseasePhysical) {

        assertDiseasePhysical(diseasePhysical);

        diseasePhysicalService.save(diseasePhysical);

        return diseasePhysical;
    }

    @Override
    public boolean deletePhysical(String id) {
        Assert.isTrue(StrUtil.isNotEmpty(id),"id不能为空");

        return diseasePhysicalService.removeById(id);
    }

    @Override
    public boolean updatePhysical(DiseasePhysical diseasePhysical) {
        Assert.isTrue(StrUtil.isNotEmpty(diseasePhysical.getDiseaseId()),"疾病id不能为空");

        return diseasePhysicalService.updateById(diseasePhysical);
    }

    @Override
    public boolean deleteByDiseaseId(String diseaseId) {

        Assert.notEmpty(diseaseId,"疾病id不能为空");
        return diseasePhysicalService.lambdaUpdate().eq(DiseasePhysical::getDiseaseId,diseaseId).remove();
    }


    private void assertDiseasePhysical(DiseasePhysical diseasePhysical){

        Assert.isTrue(StrUtil.isNotEmpty(diseasePhysical.getDiseaseId()),"疾病id不能为空");

        Assert.notNull(diseasePhysical.getPrimarilyDiagnosisCriteriaFlag(),"初步诊断依据不能为空");

        Assert.notNull(diseasePhysical.getBasisConfirmFlag(),"证实诊断依据不能为空");

        Assert.notNull(diseasePhysical.getBasisIdentificationFlag(),"鉴别诊断依据不能为空");

        Assert.notNull(diseasePhysical.getFullCheckFlag(),"全面诊断不能为空");

        Assert.notNull(diseasePhysical.getDiagnosisAssessmentFlag(),"判断不能为空");

        Assert.notNull(diseasePhysical.getRequireCheckFlag(),"是否必查不能为空");

        Assert.notNull(diseasePhysical.getDiagnosisAssessmentFlag(),"判断不能为空");

        Assert.notNull(diseasePhysical.getExpectedDiagnosisResult(),"预期诊断结果不能为空");

    }

}
